@@ -542,8 +542,7 @@ bool Aquamarine::CWaylandOutput::test() {
 }
 
 bool Aquamarine::CWaylandOutput::commit() {
-    Vector2D pixelSize   = {};
-    uint32_t refreshRate = 0;
+    Vector2D pixelSize = {};
 
     if (state->internalState.customMode)
         pixelSize = state->internalState.customMode->pixelSize;
@@ -566,7 +565,7 @@ bool Aquamarine::CWaylandOutput::commit() {
         return true;
     }
 
-    if (!swapchain->reconfigure(SSwapchainOptions{.length = 2, .size = pixelSize, .format = format})) {
+    if (!swapchain->reconfigure(SSwapchainOptions{.length = swapchain->currentOptions().length, .size = pixelSize, .format = format})) {
         backend->backend->log(AQ_LOG_ERROR, std::format("Output {}: pending state rejected: swapchain failed reconfiguring", name));
         return false;
     }
